# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to tweak the test suite if we don't have Test::More ≥ 0.88
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

# We need to tweak the test suite if we don't have Test::Builder ≥ 0.33
%global old_test_builder %(perl -MTest::Builder -e 'print (($Test::Builder::VERSION < 0.33) ? 1 : 0);' 2>/dev/null || echo 0)

# RPM version needs 4 digits after the decimal to preserve upgrade path
%global module_version 0.64
%global RPM_version %(printf "%.4f" %{module_version})

Name:		perl-Test-Differences
Version:	%{RPM_version}
Release:	4.%{__distinit}%{__distvers}
Summary:	Test strings and data structures and show differences if not OK
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/Test-Differences/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DC/DCANTRELL/Test-Differences-%{module_version}.tar.gz
Patch0:		Test-Differences-0.64-old-Test::More.patch
Patch1:		Test-Differences-0.63-old-Test::Builder.patch
Patch2:		Test-Differences-0.64-deps.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(Text::Diff) >= 1.43
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Capture::Tiny) >= 0.24
BuildRequires:	perl(Pod::Coverage) >= 0.18
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 1.22
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
When the code you're testing returns multiple lines, records or data
structures and they're just plain wrong, an equivalent to the Unix
diff utility may be just what's needed.

%prep
%setup -q -n Test-Differences-%{module_version}

# We need to tweak the test suite if we don't have Test::More ≥ 0.88
%if %{old_test_more}
%patch0
%endif

# We need to tweak the test suite if we don't have Test::Builder ≥ 0.33
%if %{old_test_builder}
%patch1
%endif

# perl dependency generator on F-7 to F-17 inclusive (and EL-5 too)
# strangely fails to pick up dependencies without this tweak
%patch2

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%doc Changes README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Differences.3*

%changelog
* Fri Sep 30 2016 Paul Howarth <paul@city-fan.org> - 0.6400-4
- Fix FTBFS when perl is not in the minimal buildroot
- BR: perl-generators where available
- Simplify find command using -delete

* Tue Nov 24 2015 Paul Howarth <paul@city-fan.org> - 0.6400-1
- Update to 0.64
  - Bump dependency version for Text::Diff to avoid a buggy release
  - Make tests pass with relocation perl (CPAN RT#103133)
- Update patches as needed

* Tue Dec  9 2014 Paul Howarth <paul@city-fan.org> - 0.6300-2
- Make sure dependencies are picked up on old distributions

* Fri Nov 21 2014 Paul Howarth <paul@city-fan.org> - 0.6300-1
- Update to 0.63
  - Minor doco-fixes
  - Remove use of flatten, always use Data::Dumper for saner, more readable
    output (CPAN RT#95446)
- Classify buildreqs by usage
- Update patches as needed

* Thu Jun 26 2014 Paul Howarth <paul@city-fan.org> - 0.6200-1
- Update to 0.62
  - Document the Text::Diff unicode fix
  - Add ability to customize 'Got' and 'Expected' column headers
- This release by DCANTRELL → update source URL
- Add patch to support building with Test::More < 0.88
- Add patch to support building with Test::Builder < 0.33
- Drop %%defattr, redundant since rpm 4.4

* Wed Jul  4 2012 Paul Howarth <paul@city-fan.org> - 0.6100-3
- BR:/R: perl(Data::Dumper)
- BR: perl(Carp), perl(constant) and perl(Exporter)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Thu Jul  7 2011 Paul Howarth <paul@city-fan.org> - 0.6100-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Apr 18 2011 Paul Howarth <paul@city-fan.org> - 0.6100-1
- Update to 0.61
  - Make '' and undef not equal
  - Made Data::Dumper minimum version 2.126 to resolve CPAN RT#60798
  - Allow an option to override Sortkeys in C<eq_or_diff>
  - Unnumbered tests; there's no point to them
- Nobody else likes macros for commands

* Thu Jul  8 2010 Paul Howarth <paul@city-fan.org> - 0.5000-2
- Add manual dependency on perl(Text::Diff) >= 0.35, not automatically detected

* Tue Jun 29 2010 Paul Howarth <paul@city-fan.org> - 0.5000-1
- Update to 0.500
  - Add support for all diff styles supplied by Text::Diff (CPAN RT#23579)
  - Add Build.PL
  - Convert to universally use Test::More instead of Test
  - Convert to modern Perl distribution.
  - Applied doc suggestion from CPAN RT#24297
  - Fix the { a => 1 } versus { a => '1' } bug (CPAN RT#3029)
- Upstream dropped eg/ docs
- Bump perl(Text::Diff) requirement to 0.35
- BR: perl(Test::Pod) and perl(Test::Pod::Coverage) for extra test cover

* Mon Jun 28 2010 Paul Howarth <paul@city-fan.org> - 0.4801-6
- Import from Fedora

* Thu May  6 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.4801-5
- Mass rebuild with perl-5.12.0

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 0.4801-4
- Rebuild against perl 5.10.1

* Wed Aug 19 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 0.4801-3
- Fix source url

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4801-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Mar 13 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 0.4801-1
- Update to 0.4801

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.47-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.47-4
- Rebuild for perl 5.10 (again)

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.47-3
- Rebuild for new perl

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.47-2.2
- Add BR: perl(Test::More)

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.47-2.1
- Correct license tag
- Add BR: perl(ExtUtils::MakeMaker)

* Sun May 14 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.47-2
- Bumping release (repodata checksum inconsistency for previous release)

* Mon May  1 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.47-1
- First build
